==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_functions/mp6005_001/MP6005_GetExtMenusHierarchy_001.java <==

package net.datastream.schemas.mp_functions.mp6005_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EXTMENUSHIERARCHYREQUEST_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="ExtMenusHierarchy" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="request" type="{http://schemas.datastream.net/MP_fields}EXTMENUSHIERARCHYREQUEST_Type" default="All" />
 *       &lt;attribute name="mobile" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "usergroupid"
})
@XmlRootElement(name = "MP6005_GetExtMenusHierarchy_001")
public class MP6005_GetExtMenusHierarchy_001 {

    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "request")
    protected EXTMENUSHIERARCHYREQUEST_Type request;
    @XmlAttribute(name = "mobile")
    protected String mobile;

    /**
     * Obtient la valeur de la propriété usergroupid.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Définit la valeur de la propriété usergroupid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.EXT_MENUS_HIERARCHY;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété request.
     * 
     * @return
     *     possible object is
     *     {@link EXTMENUSHIERARCHYREQUEST_Type }
     *     
     */
    public EXTMENUSHIERARCHYREQUEST_Type getRequest() {
        if (request == null) {
            return EXTMENUSHIERARCHYREQUEST_Type.ALL;
        } else {
            return request;
        }
    }

    /**
     * Définit la valeur de la propriété request.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMENUSHIERARCHYREQUEST_Type }
     *     
     */
    public void setRequest(EXTMENUSHIERARCHYREQUEST_Type value) {
        this.request = value;
    }

    /**
     * Obtient la valeur de la propriété mobile.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMobile() {
        if (mobile == null) {
            return "false";
        } else {
            return mobile;
        }
    }

    /**
     * Définit la valeur de la propriété mobile.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMobile(String value) {
        this.mobile = value;
    }

}

==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_functions/mp6005_001/MP6005_GetExtMenusHierarchy_001.java <==

package net.datastream.schemas.mp_functions.mp6005_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EXTMAINMENUTYPE_Type;
import net.datastream.schemas.mp_fields.EXTMENUSHIERARCHYREQUEST_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="ExtMenusHierarchy" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="request" type="{http://schemas.datastream.net/MP_fields}EXTMENUSHIERARCHYREQUEST_Type" default="All" />
 *       &lt;attribute name="mobile" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="mainmenutype" type="{http://schemas.datastream.net/MP_fields}EXTMAINMENUTYPE_Type" default="BASE" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "usergroupid"
})
@XmlRootElement(name = "MP6005_GetExtMenusHierarchy_001")
public class MP6005_GetExtMenusHierarchy_001 {

    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "request")
    protected EXTMENUSHIERARCHYREQUEST_Type request;
    @XmlAttribute(name = "mobile")
    protected String mobile;
    @XmlAttribute(name = "mainmenutype")
    protected EXTMAINMENUTYPE_Type mainmenutype;

    /**
     * Obtient la valeur de la propriété usergroupid.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Définit la valeur de la propriété usergroupid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.EXT_MENUS_HIERARCHY;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété request.
     * 
     * @return
     *     possible object is
     *     {@link EXTMENUSHIERARCHYREQUEST_Type }
     *     
     */
    public EXTMENUSHIERARCHYREQUEST_Type getRequest() {
        if (request == null) {
            return EXTMENUSHIERARCHYREQUEST_Type.ALL;
        } else {
            return request;
        }
    }

    /**
     * Définit la valeur de la propriété request.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMENUSHIERARCHYREQUEST_Type }
     *     
     */
    public void setRequest(EXTMENUSHIERARCHYREQUEST_Type value) {
        this.request = value;
    }

    /**
     * Obtient la valeur de la propriété mobile.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMobile() {
        if (mobile == null) {
            return "false";
        } else {
            return mobile;
        }
    }

    /**
     * Définit la valeur de la propriété mobile.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMobile(String value) {
        this.mobile = value;
    }

    /**
     * Obtient la valeur de la propriété mainmenutype.
     * 
     * @return
     *     possible object is
     *     {@link EXTMAINMENUTYPE_Type }
     *     
     */
    public EXTMAINMENUTYPE_Type getMainmenutype() {
        if (mainmenutype == null) {
            return EXTMAINMENUTYPE_Type.BASE;
        } else {
            return mainmenutype;
        }
    }

    /**
     * Définit la valeur de la propriété mainmenutype.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMAINMENUTYPE_Type }
     *     
     */
    public void setMainmenutype(EXTMAINMENUTYPE_Type value) {
        this.mainmenutype = value;
    }

}
